==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_entities/documentassociation_001/DOCUMENTINFO_Type.java <==

package net.datastream.schemas.mp_entities.documentassociation_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DOCUMENTINFO_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DOCUMENTINFO_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="documentDescription" type="{http://schemas.datastream.net/MP_fields}CODE80_Type" />
 *       &lt;attribute name="documentFileName" type="{http://schemas.datastream.net/MP_fields}CODE255_Type" />
 *       &lt;attribute name="documentFileType" type="{http://schemas.datastream.net/MP_fields}CODE50_Type" />
 *       &lt;attribute name="documentType" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" />
 *       &lt;attribute name="documentOrganizationCode" type="{http://schemas.datastream.net/MP_fields}CODE15_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DOCUMENTINFO_Type")
public class DOCUMENTINFO_Type {

    @XmlAttribute(name = "documentDescription")
    protected String documentDescription;
    @XmlAttribute(name = "documentFileName")
    protected String documentFileName;
    @XmlAttribute(name = "documentFileType")
    protected String documentFileType;
    @XmlAttribute(name = "documentType")
    protected String documentType;
    @XmlAttribute(name = "documentOrganizationCode")
    protected String documentOrganizationCode;

    /**
     * Gets the value of the documentDescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentDescription() {
        return documentDescription;
    }

    /**
     * Sets the value of the documentDescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentDescription(String value) {
        this.documentDescription = value;
    }

    /**
     * Gets the value of the documentFileName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentFileName() {
        return documentFileName;
    }

    /**
     * Sets the value of the documentFileName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentFileName(String value) {
        this.documentFileName = value;
    }

    /**
     * Gets the value of the documentFileType property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentFileType() {
        return documentFileType;
    }

    /**
     * Sets the value of the documentFileType property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentFileType(String value) {
        this.documentFileType = value;
    }

    /**
     * Gets the value of the documentType property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentType() {
        return documentType;
    }

    /**
     * Sets the value of the documentType property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentType(String value) {
        this.documentType = value;
    }

    /**
     * Gets the value of the documentOrganizationCode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentOrganizationCode() {
        return documentOrganizationCode;
    }

    /**
     * Sets the value of the documentOrganizationCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentOrganizationCode(String value) {
        this.documentOrganizationCode = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_entities/documentassociation_001/DOCUMENTINFO_Type.java <==

package net.datastream.schemas.mp_entities.documentassociation_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DOCUMENTINFO_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DOCUMENTINFO_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="documentDescription" type="{http://schemas.datastream.net/MP_fields}CODE80_Type" />
 *       &lt;attribute name="documentFileName" type="{http://schemas.datastream.net/MP_fields}CODE255_Type" />
 *       &lt;attribute name="documentFileType" type="{http://schemas.datastream.net/MP_fields}CODE50_Type" />
 *       &lt;attribute name="documentType" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" />
 *       &lt;attribute name="documentOrganizationCode" type="{http://schemas.datastream.net/MP_fields}CODE15_Type" />
 *       &lt;attribute name="is_documentauth_update" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DOCUMENTINFO_Type")
public class DOCUMENTINFO_Type {

    @XmlAttribute(name = "documentDescription")
    protected String documentDescription;
    @XmlAttribute(name = "documentFileName")
    protected String documentFileName;
    @XmlAttribute(name = "documentFileType")
    protected String documentFileType;
    @XmlAttribute(name = "documentType")
    protected String documentType;
    @XmlAttribute(name = "documentOrganizationCode")
    protected String documentOrganizationCode;
    @XmlAttribute(name = "is_documentauth_update")
    protected String is_Documentauth_Update;

    /**
     * Gets the value of the documentDescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentDescription() {
        return documentDescription;
    }

    /**
     * Sets the value of the documentDescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentDescription(String value) {
        this.documentDescription = value;
    }

    /**
     * Gets the value of the documentFileName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentFileName() {
        return documentFileName;
    }

    /**
     * Sets the value of the documentFileName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentFileName(String value) {
        this.documentFileName = value;
    }

    /**
     * Gets the value of the documentFileType property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentFileType() {
        return documentFileType;
    }

    /**
     * Sets the value of the documentFileType property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentFileType(String value) {
        this.documentFileType = value;
    }

    /**
     * Gets the value of the documentType property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentType() {
        return documentType;
    }

    /**
     * Sets the value of the documentType property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentType(String value) {
        this.documentType = value;
    }

    /**
     * Gets the value of the documentOrganizationCode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocumentOrganizationCode() {
        return documentOrganizationCode;
    }

    /**
     * Sets the value of the documentOrganizationCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocumentOrganizationCode(String value) {
        this.documentOrganizationCode = value;
    }

    /**
     * Gets the value of the is_Documentauth_Update property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Documentauth_Update() {
        return is_Documentauth_Update;
    }

    /**
     * Sets the value of the is_Documentauth_Update property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Documentauth_Update(String value) {
        this.is_Documentauth_Update = value;
    }

}
